@@ -6,7 +6,9 @@ use core::fmt::{Debug, Formatter, Result};
 use core::hash::{Hash, Hasher};
 use core::iter::FromIterator;
 use core::mem::MaybeUninit;
-use core::ops::{Index, IndexMut, Range, RangeInclusive};
+use core::ops::{Index, IndexMut, Range, RangeFull, RangeInclusive};
+#[cfg(feature = "std")]
+use std::io::{self, Error, ErrorKind, IoSlice, Read, Write};
 
 impl<T, const N: usize> AsMut<T> for StaticVec<T, {N}> {
   ///Asserts that the StaticVec's current length is greater than 0 to avoid
@@ -262,6 +264,25 @@ impl<T, const N: usize> IndexMut<Range<usize>> for StaticVec<T, {N}> {
   }
 }
 
+impl<T, const N: usize> Index<RangeFull> for StaticVec<T, {N}> {
+  type Output = [T];
+  ///Returns a constant reference to a slice consisting of `0..self.length`
+  //elements of the StaticVec, using [as_slice](crate::StaticVec::as_slice) internally.
+  #[inline(always)]
+  fn index(&self, _index: RangeFull) -> &Self::Output {
+    self.as_slice()
+  }
+}
+
+impl<T, const N: usize> IndexMut<RangeFull> for StaticVec<T, {N}> {
+  ///Returns a mutable reference to a slice consisting of `0..self.length`
+  //elements of the StaticVec, using [as_mut_slice](crate::StaticVec::as_mut_slice) internally.
+  #[inline(always)]
+  fn index_mut(&mut self, _index: RangeFull) -> &mut Self::Output {
+    self.as_mut_slice()
+  }
+}
+
 impl<T, const N: usize> Index<RangeInclusive<usize>> for StaticVec<T, {N}> {
   type Output = [T];
   ///Asserts that the lower bound of `index` is less than or equal to its upper bound,
@@ -435,3 +456,53 @@ impl_partial_ord_with_as_slice_against_slice!([T1], &StaticVec<T2, {N}>);
 impl_partial_ord_with_as_slice_against_slice!([T1], &mut StaticVec<T2, {N}>);
 impl_partial_ord_with_as_slice_against_slice!(&[T1], StaticVec<T2, {N}>);
 impl_partial_ord_with_as_slice_against_slice!(&mut [T1], StaticVec<T2, {N}>);
+
+#[cfg(feature = "std")]
+impl<const N: usize> Read for StaticVec<u8, {N}> {
+  #[inline]
+  fn read(&mut self, buf: &mut [u8]) -> io::Result<usize> {
+    let buf_len = buf.len();
+    if buf_len <= N {
+      unsafe {
+        buf.copy_from_slice(self.as_slice().get_unchecked(0..buf_len));
+      }
+      Ok(buf_len)
+    } else {
+      Err(Error::new(ErrorKind::Other, "Not enough data available!"))
+    }
+  }
+}
+
+#[cfg(feature = "std")]
+impl<const N: usize> Write for StaticVec<u8, {N}> {
+  #[inline(always)]
+  fn write(&mut self, buf: &[u8]) -> io::Result<usize> {
+    let old_length = self.length;
+    self.extend_from_slice(buf);
+    Ok(self.length - old_length)
+  }
+
+  #[inline]
+  fn write_vectored(&mut self, bufs: &[IoSlice<'_>]) -> io::Result<usize> {
+    let len = bufs.iter().map(|b| b.len()).sum();
+    if self.length + len <= N {
+      for buf in bufs {
+        self.extend_from_slice(buf);
+      }
+      Ok(len)
+    } else {
+      Err(Error::new(ErrorKind::Other, "No space left!"))
+    }
+  }
+
+  #[inline(always)]
+  fn write_all(&mut self, buf: &[u8]) -> io::Result<()> {
+    self.extend_from_slice(buf);
+    Ok(())
+  }
+
+  #[inline(always)]
+  fn flush(&mut self) -> io::Result<()> {
+    Ok(())
+  }
+}
