@@ -42,6 +42,13 @@ fn clear() {
   assert!(v.is_empty());
 }
 
+#[test]
+fn clone() {
+  let v = staticvec![1, 2, 3, 4, 5, 6, 7, 8];
+  let vv = v.clone();
+  assert_eq!(v, vv);
+}
+
 #[test]
 fn dedup() {
   let mut vec = staticvec![1, 2, 2, 3, 2];
@@ -195,6 +202,8 @@ fn new_from_slice() {
   assert_eq!(vec, [1, 2, 3]);
   let vec2 = StaticVec::<i32, 3>::new_from_slice(&[1, 2, 3, 4, 5, 6]);
   assert_eq!(vec2, [1, 2, 3]);
+  let vec3 = StaticVec::<i32, 27>::new_from_slice(&[]);
+  assert_eq!(vec3, []);
 }
 
 #[test]
@@ -203,6 +212,55 @@ fn new_from_array() {
   assert_eq!(vec, [1, 1, 1]);
   let vec2 = StaticVec::<i32, 3>::new_from_array([1; 6]);
   assert_eq!(vec2, [1, 1, 1]);
+  let vec3 = StaticVec::<i32, 27>::new_from_array([0; 0]);
+  assert_eq!(vec3, []);
+}
+
+#[test]
+fn partial_eq() {
+  assert_eq!(StaticVec::<i32, 0>::new(), [0; 0]);
+  assert_eq!(StaticVec::<i32, 0>::new(), []);
+  assert_eq!(StaticVec::<i32, 0>::new(), &[]);
+  assert_eq!(StaticVec::<i32, 0>::new(), &mut []);
+  assert_eq!(StaticVec::<i32, 0>::new(), StaticVec::<i32, 0>::new());
+  assert_eq!(StaticVec::<i32, 0>::new(), &StaticVec::<i32, 0>::new());
+  assert_eq!(StaticVec::<i32, 0>::new(), &mut StaticVec::<i32, 0>::new());
+  //assert_eq! is written in a way that's limited by LengthAtMost32, so I can't
+  //use it for the next part.
+  if staticvec![1; 64] != [1; 64] {
+    panic!();
+  }
+  if &staticvec![1; 64] != [1; 64] {
+    panic!();
+  }
+  if &mut staticvec![1; 64] != [1; 64] {
+    panic!();
+  }
+  if staticvec![1; 64] != &[1; 64] {
+    panic!();
+  }
+  if staticvec![1; 64] != &mut [1; 64] {
+    panic!();
+  }
+  if staticvec![1; 64] != staticvec![1; 64] {
+    panic!();
+  }
+  if staticvec![1; 64] != &staticvec![1; 64] {
+    panic!();
+  }
+  if staticvec![1; 64] != &mut staticvec![1; 64] {
+    panic!();
+  }
+}
+
+#[test]
+fn partial_ord() {
+  //TODO: add more here.
+  assert!(staticvec![1] < staticvec![2]);
+  assert!(staticvec![1] > []);
+  assert!(staticvec![1] <= &staticvec![2]);
+  assert!(staticvec![1] >= &[]);
+  assert!(staticvec![1] > &mut []);
 }
 
 #[test]
@@ -219,6 +277,15 @@ fn push() {
   assert_eq!(vec, [1, 2, 3, 3]);
 }
 
+#[cfg(feature = "std")]
+#[test]
+fn read() {
+  let mut ints = staticvec![1, 2, 3, 4, 6, 7, 8, 9, 10];
+  let mut buffer = staticvec![0; 4];
+  assert_eq!(ints.read(buffer.as_mut_slice()).unwrap(), 4);
+  assert_eq!(buffer, [1, 2, 3, 4]);
+}
+
 #[test]
 fn remove() {
   let mut v = staticvec![1, 2, 3];
@@ -299,6 +366,16 @@ fn split_off() {
   assert_eq!(vec2, [2, 3]);
 }
 
+#[test]
+fn swap_pop() {
+  let mut v = staticvec!["foo", "bar", "baz", "qux"];
+  assert_eq!(v.swap_pop(1).unwrap(), "bar");
+  assert_eq!(v, ["foo", "qux", "baz"]);
+  assert_eq!(v.swap_pop(0).unwrap(), "foo");
+  assert_eq!(v, ["baz", "qux"]);
+  assert_eq!(v.swap_pop(17), None);
+}
+
 #[test]
 fn swap_remove() {
   let mut v = staticvec!["foo", "bar", "baz", "qux"];
@@ -321,4 +398,17 @@ fn truncate() {
   assert_eq!(vec3, []);
   let mut vec4 = staticvec![1, 2, 3, 4];
   vec4.truncate(97);
+  assert_eq!(vec4.len(), 4);
+}
+
+#[cfg(feature = "std")]
+#[test]
+fn write() {
+  //From arrayvec
+  let mut v = StaticVec::<u8, 8>::new();
+  write!(&mut v, "\x01\x02\x03").unwrap();
+  assert_eq!(&v[..], &[1, 2, 3]);
+  let r = v.write(&[9; 16]).unwrap();
+  assert_eq!(r, 5);
+  assert_eq!(&v[..], &[1, 2, 3, 9, 9, 9, 9, 9]);
 }
